@@ -1,14 +1,14 @@
 #' Request couchdb config
 #' 
-#' Function provides access to the \code{_config} api end point
+#' Function provides access to the \code{_config} api end point.
 #' 
 #' 
 #' @param cdb Only the connection settings \code{cdb$port} and
 #' \code{cdb$serverName} is needed.
 #' @return
 #' 
-#' \item{cdb }{The result of the request is stored in \code{cdb$re} after
-#' converting the answer into a list using \code{fromJSON()}.  }
+#' \item{cdb }{The result of the request is stored in \code{cdb$res} after
+#' converting the answer into a list using \code{fromJSON()}.}
 #' @author wactbprot
 #' @export
 #' @examples
@@ -32,10 +32,11 @@ cdbGetConfig <- function(cdb){
     adrString <- paste(cdb$baseUrl(cdb),
                        "_config",
                        sep="")
-    res       <- getURL(adrString,
+
+    res       <- getURL(utils::URLencode(adrString),
                         customrequest = "GET",
-                        curl=cdb$curl
-                        )
+                        .opts         = cdb$opts(cdb),
+                        curl          = cdb$curl)
     
     return(cdb$checkRes(cdb,res))
   }else{
