@@ -28,16 +28,16 @@ cdbListDB <- function(cdb){
   
   fname <- deparse(match.call()[[1]])
   cdb   <- cdb$checkCdb(cdb,fname)
-
   
   if(cdb$error == ""){
     adrString <- paste(cdb$baseUrl(cdb), "_all_dbs",
                        sep="")
     
-    res <- getURL(adrString,
+    res <- getURL(utils::URLencode(adrString),
                   customrequest = "GET",
-                  curl=cdb$curl
-                  )
+                  curl          = cdb$curl,
+                  .opts         = cdb$opts(cdb))
+    
     return(cdb$checkRes(cdb,res))
   }else{
     stop(cdb$error)
